@@ -2,4 +2,4 @@
 
 APP_CONF = "/etc/ansible-deployer"
 CFG_PERMISSIONS = "0o644"
-SUBCOMMANDS = ("run", "list", "lock", "unlock", "verify", "show")
+SUBCOMMANDS = ("run", "lock", "unlock", "verify", "show")
